@@ -1,5 +1,4 @@
-CREATE DATABASE ocsweb;
-USE ocsweb;
+
 
 CREATE TABLE hardware (
   ID INTEGER NOT NULL auto_increment,
@@ -16,6 +15,8 @@ CREATE TABLE hardware (
   MEMORY INTEGER default NULL,
   SWAP INTEGER default NULL,
   IPADDR VARCHAR(255) default NULL,
+  DNS VARCHAR(255) default NULL,
+  DEFAULTGATEWAY VARCHAR(255) default NULL,
   ETIME DATETIME default NULL,
   LASTDATE DATETIME default NULL,
   LASTCOME DATETIME default NULL,
@@ -29,8 +30,10 @@ CREATE TABLE hardware (
   WINPRODID VARCHAR(255) default NULL,
   WINPRODKEY VARCHAR(255) default NULL,
   USERAGENT VARCHAR(50) default NULL,
-  CHECKSUM INTEGER default 0,
+  CHECKSUM BIGINT UNSIGNED default 0,
   SSTATE INTEGER default 0,
+  IPSRC VARCHAR(255) default NULL,
+  UUID VARCHAR(255) default NULL,
   PRIMARY KEY  (ID),
   INDEX NAME (NAME),
   INDEX CHECKSUM (CHECKSUM),
@@ -85,8 +88,10 @@ CREATE TABLE bios (
   BMANUFACTURER VARCHAR(255) default NULL,
   BVERSION VARCHAR(255) default NULL,
   BDATE VARCHAR(255) default NULL,
+  ASSETTAG VARCHAR(255) default NULL,
   PRIMARY KEY  (HARDWARE_ID),
-  INDEX SSN (SSN)
+  INDEX SSN (SSN),
+  INDEX ASSETTAG (ASSETTAG)
 ) ENGINE=INNODB ;
 
 CREATE TABLE config (
@@ -131,6 +136,7 @@ CREATE TABLE drives (
   FREE INTEGER default NULL,
   NUMFILES INTEGER default NULL,
   VOLUMN VARCHAR(255) default NULL,
+  CREATEDATE DATE default NULL,
   PRIMARY KEY  (ID, HARDWARE_ID)
 ) ENGINE=INNODB ;
 
@@ -204,6 +210,7 @@ CREATE TABLE networks (
   IPGATEWAY VARCHAR(255) default NULL,
   IPSUBNET VARCHAR(255) default NULL,
   IPDHCP VARCHAR(255) default NULL,
+  VIRTUALDEV BOOL default FALSE,
   PRIMARY KEY  (ID, HARDWARE_ID),
   INDEX MACADDR (MACADDR),
   INDEX IPADDRESS(IPADDRESS),
@@ -345,6 +352,19 @@ CREATE TABLE subnet (
   INDEX ID(ID)
 ) ENGINE=MYISAM ;
 
+CREATE TABLE virtualmachines (
+  ID INTEGER NOT NULL auto_increment,
+  HARDWARE_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) default NULL,
+  STATUS VARCHAR(255) default NULL,
+  SUBSYSTEM VARCHAR(255) default NULL,
+  VMTYPE VARCHAR(255) default NULL,
+  UUID VARCHAR(255) default NULL,
+  VCPU INTEGER default NULL,
+  MEMORY INTEGER default NULL,
+  PRIMARY KEY  (ID, HARDWARE_ID)
+) ENGINE=INNODB ;
+
 CREATE TABLE locks(
   HARDWARE_ID INTEGER NOT NULL PRIMARY KEY,
   ID INTEGER DEFAULT NULL,
@@ -484,7 +504,28 @@ CREATE TABLE engine_persistent (
  TVALUE varchar(255) default NULL,
   UNIQUE KEY NAME (NAME),
   KEY ID (ID)
-) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;
+) ENGINE=MyISAM DEFAULT CHARSET=latin1;
+
+CREATE TABLE journallog (
+  HARDWARE_ID INT(11) not null,
+  ID integer auto_increment not null,
+  JOURNALLOG LONGTEXT,
+  LISTENERNAME VARCHAR(255) default 'NONAME',
+  `DATE` VARCHAR(255) default null,
+  STATUS INTEGER default 0,
+  ERRORCODE INTEGER default 0,
+  PRIMARY KEY(ID,HARDWARE_ID)
+) ENGINE=INNODB;
+
+CREATE TABLE javainfo (
+  HARDWARE_ID INT(11) not null,
+  JAVANAME VARCHAR(255) default 'NONAME',
+  JAVAPATHLEVEL INTEGER default 0,
+  JAVACOUNTRY VARCHAR(255),
+  JAVACLASSPATH VARCHAR(255) default null,
+  JAVAHOME VARCHAR(255) default null,
+  PRIMARY KEY (HARDWARE_ID)
+)ENGINE=INNODB;
 
 ALTER TABLE devices ADD INDEX IVALUE (IVALUE);
 ALTER TABLE devices ADD INDEX NAME (NAME);
@@ -499,9 +540,14 @@ ALTER TABLE networks ADD INDEX IPSUBNET (IPSUBNET);
 ALTER TABLE networks ADD INDEX MACADDR (MACADDR);
 ALTER TABLE hardware ADD COLUMN CHECKSUM INTEGER default NULL;
 ALTER TABLE hardware CHANGE COLUMN CHECKSUM CHECKSUM INTEGER default 131071;
+ALTER TABLE hardware CHANGE COLUMN CHECKSUM CHECKSUM BIGINT UNSIGNED default 262143;
 ALTER TABLE hardware add column WINPRODKEY VARCHAR(255) default NULL;
 ALTER TABLE hardware add column USERDOMAIN VARCHAR(255) default NULL;
 ALTER TABLE hardware ADD COLUMN SSTATE INTEGER default 0;
+ALTER TABLE hardware ADD COLUMN DEFAULTGATEWAY VARCHAR(255) default NULL;
+ALTER TABLE hardware ADD COLUMN DNS VARCHAR(255) default NULL;
+ALTER TABLE drives ADD COLUMN CREATEDATE DATE default NULL;
+ALTER TABLE hardware ADD COLUMN IPSRC VARCHAR(255) default NULL;
 
 ALTER TABLE hardware CHANGE ID ID INTEGER;
 ALTER TABLE hardware DROP PRIMARY KEY;
@@ -515,6 +561,8 @@ ALTER TABLE bios ADD COLUMN HARDWARE_ID integer not NULL FIRST;
 UPDATE bios SET bios.HARDWARE_ID= (SELECT ID FROM hardware WHERE bios.DEVICEID = hardware.DEVICEID);
 ALTER TABLE bios DROP DEVICEID;
 ALTER TABLE bios ADD PRIMARY KEY(HARDWARE_ID);
+ALTER TABLE bios ADD COLUMN ASSETTAG VARCHAR(255) default NULL;
+ALTER TABLE bios ADD INDEX ASSETTAG (ASSETTAG);
 
 ALTER TABLE accountinfo DROP PRIMARY KEY;
 ALTER TABLE accountinfo ADD COLUMN HARDWARE_ID integer not NULL FIRST;
@@ -659,6 +707,8 @@ ALTER TABLE printers ADD INDEX ID (ID);
 ALTER TABLE printers change ID ID INTEGER auto_increment;
 ALTER TABLE printers ADD PRIMARY KEY(HARDWARE_ID,ID);
 ALTER TABLE printers DROP DEVICEID;
+ALTER TABLE printers ADD COLUMN DESCRIPTION VARCHAR(255);
+
 
 ALTER TABLE videos change ID ID INTEGER;
 ALTER TABLE videos DROP PRIMARY KEY;
@@ -724,10 +774,8 @@ INSERT INTO config VALUES ('DOWNLOAD', 0, '', 'Activate softwares auto deploymen
 INSERT INTO config VALUES ('DOWNLOAD_CYCLE_LATENCY', 60, '', 'Time between two cycles (seconds)');
 INSERT INTO config VALUES ('DOWNLOAD_PERIOD_LENGTH', 10, '', 'Number of cycles in a period');
 INSERT INTO config VALUES ('DOWNLOAD_FRAG_LATENCY', 10, '', 'Time between two downloads (seconds)');
-INSERT INTO config VALUES ('DOWNLOAD_PERIOD_LATENCY', 0, '', 'Time between two periods (seconds)');
+INSERT INTO config VALUES ('DOWNLOAD_PERIOD_LATENCY', 1, '', 'Time between two periods (seconds)');
 INSERT INTO config VALUES ('DOWNLOAD_TIMEOUT', 30, '', 'Validity of a package (in days)');
-INSERT INTO config VALUES ('LOCAL_SERVER', 0, 'localhost', 'Server address used for local import');
-INSERT INTO config VALUES ('LOCAL_PORT', 80, '', 'Server port used for local import');
 INSERT INTO config VALUES ('DOWNLOAD_PACK_DIR','','/var/lib/ocsinventory-reports','Directory for download files');
 INSERT INTO config VALUES ('IPDISCOVER_IPD_DIR','','/var/lib/ocsinventory-reports','Directory for Ipdiscover files');
 
@@ -735,12 +783,9 @@ INSERT INTO blacklist_serials(SERIAL) VALUES ('N/A'),('(null string)'),('INVALID
 INSERT INTO blacklist_macaddresses(MACADDRESS) VALUES ('00:00:00:00:00:00'),('FF:FF:FF:FF:FF:FF'),('44:45:53:54:00:00'),('44:45:53:54:00:01'),('00:01:02:7D:9B:1C'),('00:08:A1:46:06:35'),('00:08:A1:66:E2:1A'),('00:09:DD:10:37:68'),('00:0F:EA:9A:E2:F0'),('00:10:5A:72:71:F3'),('00:11:11:85:08:8B'),('10:11:11:11:11:11'),('44:45:53:54:61:6F'),('');
 
 
-INSERT INTO operators VALUES ('admin','admin','admin','admin',1, 'Default administrator account');
+INSERT INTO operators(ID,FIRSTNAME,LASTNAME,PASSWD,ACCESSLVL,COMMENTS) VALUES ('admin','admin','admin','admin',1, 'Default administrator account');
 
-GRANT ALL PRIVILEGES ON ocsweb.* TO ocs IDENTIFIED BY 'ocs';
-GRANT ALL PRIVILEGES ON ocsweb.* TO ocs@localhost IDENTIFIED BY 'ocs';
-
-INSERT INTO config VALUES ('GUI_VERSION', 0, '5003', 'Version of the installed GUI and database');
+INSERT INTO config VALUES ('GUI_VERSION', 0, '6005', 'Version of the installed GUI and database');
 
 CREATE TABLE download_servers (
   HARDWARE_ID int(11) NOT NULL,
@@ -800,6 +845,7 @@ insert into config (NAME,IVALUE,TVALUE,COMMENTS) values ('GUI_REPORT_AGIN_MACH',
 ALTER TABLE download_enable ADD SERVER_ID INT(11);
 ALTER TABLE download_enable ADD GROUP_ID INT(11);
 ALTER TABLE groups ADD REVALIDATE_FROM INT(11);
+ALTER TABLE groups ADD XMLDEF longtext;
 
 CREATE TABLE prolog_conntrack (
   ID int(11) NOT NULL auto_increment,
@@ -809,3 +855,503 @@ CREATE TABLE prolog_conntrack (
   KEY ID (ID),
   KEY DEVICEID (DEVICEID)
 ) ENGINE=MEMORY; 
+
+CREATE TABLE itmgmt_comments (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  HARDWARE_ID int(11) NOT NULL,
+  COMMENTS longtext,
+  USER_INSERT varchar(100) DEFAULT NULL,
+  DATE_INSERT date DEFAULT NULL,
+  ACTION varchar(255) DEFAULT NULL,
+  VISIBLE int(11) DEFAULT NULL,
+  PRIMARY KEY (`ID`)
+) ENGINE=MyISAM;
+
+UPDATE operators SET passwd=md5('admin') where ID='admin';
+
+CREATE TABLE languages (
+  NAME varchar(60) COLLATE latin1_general_ci NOT NULL,
+  IMG blob,
+  JSON_VALUE longtext CHARACTER SET latin1,
+  PRIMARY KEY (NAME)
+) ENGINE=MyISAM;
+
+CREATE TABLE temp_files (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  TABLE_NAME varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  FIELDS_NAME varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  FILE blob,
+  COMMENT longtext CHARACTER SET latin1,
+  AUTHOR varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  FILE_NAME varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  FILE_TYPE varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  FILE_SIZE int(11) DEFAULT NULL,
+  ID_DDE int(11) DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+
+
+ALTER TABLE networks ADD COLUMN VIRTUALDEV BOOL not NULL DEFAULT FALSE;
+ALTER TABLE hardware ADD COLUMN UUID VARCHAR(255) default NULL;
+ALTER TABLE operators ADD COLUMN NEW_ACCESSLVL VARCHAR(255) default NULL;
+ALTER TABLE operators ADD COLUMN EMAIL VARCHAR(255) default NULL;
+UPDATE operators SET NEW_ACCESSLVL='sadmin' where ACCESSLVL=1;
+UPDATE operators SET NEW_ACCESSLVL='ladmin' where ACCESSLVL=2;
+UPDATE operators SET NEW_ACCESSLVL='admin' where ACCESSLVL=3;
+ALTER TABLE operators ADD COLUMN USER_GROUP VARCHAR(255) default NULL;
+ALTER TABLE download_available ADD COLUMN ID_WK int(11) default NULL;
+
+CREATE TABLE downloadwk_tab_values (
+  FIELD varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  VALUE varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  LBL varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  DEFAULT_FIELD int(1) DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM AUTO_INCREMENT=6 DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+INSERT INTO downloadwk_tab_values (ID,FIELD,VALUE,LBL,DEFAULT_FIELD) values (1,'TAB','INFO_DEM','1033',1);
+INSERT INTO downloadwk_tab_values (ID,FIELD,VALUE,LBL,DEFAULT_FIELD) values (2,'TAB','INFO_PAQUET','1034',1);
+INSERT INTO downloadwk_tab_values (ID,FIELD,VALUE,LBL,DEFAULT_FIELD) values (3,'TAB','INFO_CONF','1035',1);
+INSERT INTO downloadwk_tab_values (ID,FIELD,VALUE,LBL,DEFAULT_FIELD) values (4,'TAB','INFO_VALID','1036',1);
+INSERT INTO downloadwk_tab_values (ID,FIELD,VALUE,LBL,DEFAULT_FIELD) values (5,'TAB','INFO_HISTO','1052',1);
+
+CREATE TABLE downloadwk_fields (
+  TAB varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  FIELD varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  TYPE int(11) DEFAULT NULL,
+  LBL varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  MUST_COMPLETED int(11) DEFAULT NULL,
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  VALUE varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  DEFAULT_FIELD int(1) DEFAULT NULL,
+  RESTRICTED int(1) DEFAULT NULL,
+  LINK_STATUS int(11) DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (1,'USER',3,1038,1,'loggeduser',1,0,0,1);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (2,'NAME_TELEDEPLOY',0,1037,1,'',1,0,0,2);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (2,'INFO_PACK',0,53,1,'',1,0,0,3);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (3,'PRIORITY',2,1039,1,'',1,0,0,4);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (3,'NOTIF_USER',2,1040,1,'',1,0,0,5);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (3,'REPORT_USER',2,1041,1,'',1,0,0,6);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (3,'REBOOT',2,1042,1,'',1,0,0,7);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (4,'VALID_INSTALL',6,1043,1,'',1,0,0,8);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (4,'STATUS',2,1046,0,'2',1,1,0,9);
+INSERT INTO downloadwk_fields (TAB,FIELD,TYPE,LBL,MUST_COMPLETED,VALUE,DEFAULT_FIELD,RESTRICTED,LINK_STATUS,ID) values (5,'LIST_HISTO',10,1052,0,'select AUTHOR,DATE,ACTION from downloadwk_history where id_dde=%s$$$$OLD_MODIF',1,0,0,10);
+
+CREATE TABLE downloadwk_pack (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  LOGIN_USER varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  GROUP_USER varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  Q_DATE int(11) DEFAULT NULL,
+  fields_1 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_2 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_3 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_4 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_5 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_6 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_7 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_8 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_9 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  fields_10 varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+CREATE TABLE downloadwk_statut_request (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  NAME varchar(20) COLLATE latin1_general_ci DEFAULT NULL,
+  LBL varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  ACTIF int(11) DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM AUTO_INCREMENT=10 DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (1,'NIV0','DELETE',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (2,'NIV1','WAITING FOR INCLUSION',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (3,'NIV2','ACKNOWLEDGEMENT',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (4,'NIV3','REFUSAL',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (5,'NIV4','NEED TO CHANGE',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (6,'NIV5','CREATE PACKAGE',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (7,'NIV6','LOCAL TEST',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (8,'NIV7','PERIMETER LIMITED DEPLOYMENT',0);
+INSERT INTO downloadwk_statut_request (ID,NAME,LBL,ACTIF) values (9,'NIV8','DURING DEPLOYMENT',0);
+
+CREATE TABLE downloadwk_conf_values (
+  FIELD int(11) DEFAULT NULL,
+  VALUE varchar(100) COLLATE latin1_general_ci DEFAULT NULL,
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  DEFAULT_FIELD int(1) DEFAULT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+CREATE TABLE downloadwk_history (
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  ID_DDE int(11) DEFAULT NULL,
+  AUTHOR varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  DATE date DEFAULT NULL,
+  ACTION longtext CHARACTER SET latin1,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+CREATE TABLE accountinfo_config(
+  ID int(11) NOT NULL AUTO_INCREMENT,
+  NAME_ACCOUNTINFO varchar(255) DEFAULT NULL,
+  TYPE int(11) DEFAULT NULL,
+  NAME varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  ID_TAB int(11) DEFAULT NULL,
+  COMMENT varchar(255) COLLATE latin1_general_ci DEFAULT NULL,
+  SHOW_ORDER int(11) NOT NULL,
+  PRIMARY KEY (ID)
+) ENGINE=MyISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+insert into config (NAME,IVALUE,TVALUE,COMMENTS) values ('TAB_ACCOUNTAG_1',1,'TAG','Default TAB on computers accountinfo');
+insert into config (NAME,IVALUE,TVALUE,COMMENTS) values ('TAB_ACCOUNTSNMP_1',1,'TAG','Default TAB on snmp accountinfo');
+ALTER TABLE subnet CHANGE ID ID VARCHAR(255);
+
+CREATE TABLE blacklist_subnet(
+	ID INTEGER auto_increment,
+	SUBNET VARCHAR(255),
+	MASK VARCHAR(255),
+	PRIMARY KEY(SUBNET,MASK),
+	INDEX ID(ID)
+) ENGINE = MYISAM DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
+
+ALTER TABLE accountinfo_config ADD COLUMN ACCOUNT_TYPE VARCHAR(255) default NULL;
+INSERT INTO accountinfo_config VALUES (1,'TAG',0,'TAG',1,'TAG',1,'COMPUTERS'),(2,'TAG',0,'TAG',1,'TAG',1,'SNMP');
+UPDATE accountinfo_config SET ACCOUNT_TYPE='COMPUTERS' where ACCOUNT_TYPE IS NULL;
+
+
+CREATE TABLE snmp_accountinfo (
+  SNMP_ID INTEGER NOT NULL,
+  TAG VARCHAR(255) default 'NA',
+  primary key(SNMP_ID),
+  INDEX TAG (TAG)
+) ENGINE=INNODB ;
+
+insert into config (NAME,IVALUE,COMMENTS) values ('SNMP_INVENTORY_DIFF',1,'Configure engine to update snmp inventory regarding to snmp_laststate table (lower DB backend load)');
+INSERT INTO config VALUES ('SNMP_DIR','','/var/lib/ocsinventory-reports/snmp','Directory for download files');
+
+ALTER TABLE softwares ADD COLUMN GUID VARCHAR(255) DEFAULT NULL;
+ALTER TABLE softwares ADD COLUMN LANGUAGE VARCHAR(255) DEFAULT NULL;
+ALTER TABLE softwares ADD COLUMN INSTALLDATE DATETIME DEFAULT NULL ;
+ALTER TABLE softwares ADD COLUMN BITSWIDTH int(11) DEFAULT NULL;
+
+
+CREATE TABLE snmp (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  IPADDR VARCHAR(255) DEFAULT NULL,
+  MACADDR VARCHAR(255) NOT NULL,
+  SNMPDEVICEID VARCHAR(255) NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  CONTACT VARCHAR(255) DEFAULT NULL,
+  LOCATION VARCHAR(255) DEFAULT NULL,
+  UPTIME VARCHAR(255) DEFAULT NULL,
+  DOMAIN VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  LASTDATE DATETIME default NULL,
+  CHECKSUM BIGINT UNSIGNED DEFAULT 0,
+  PRIMARY KEY (ID) 
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_printers (
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  COUNTER VARCHAR(255) DEFAULT NULL,
+  STATUS VARCHAR(255) DEFAULT NULL,
+  ERRORSTATE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_trays (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  LEVEL VARCHAR(255) DEFAULT NULL,
+  MAXCAPACITY INTEGER DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_cartridges (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  LEVEL INTEGER DEFAULT NULL,
+  MAXCAPACITY INTEGER DEFAULT NULL,
+  COLOR VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_networks (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  MACADDR VARCHAR(255) DEFAULT NULL,
+  DEVICEMACADDR VARCHAR(255) DEFAULT NULL,
+  SLOT VARCHAR(255) DEFAULT NULL,
+  STATUS VARCHAR(255) DEFAULT NULL,
+  SPEED VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  DEVICEADDRESS VARCHAR(255) DEFAULT NULL,
+  DEVICENAME VARCHAR(255) DEFAULT NULL,
+  DEVICEPORT VARCHAR(255) DEFAULT NULL,
+  DEVICETYPE VARCHAR(255) DEFAULT NULL,
+  TYPEMIB VARCHAR(255) DEFAULT NULL,
+  IPADDR VARCHAR(255) DEFAULT NULL,
+  IPMASK VARCHAR(255) DEFAULT NULL,
+  IPGATEWAY VARCHAR(255) DEFAULT NULL,
+  IPSUBNET VARCHAR(255) DEFAULT NULL,
+  IPDHCP VARCHAR(255) DEFAULT NULL,
+  DRIVER VARCHAR(255) DEFAULT NULL,
+  VIRTUALDEV INTEGER NOT NULL DEFAULT 0,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_switchs (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  REFERENCE VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  SOFTVERSION VARCHAR(255) DEFAULT NULL,
+  FIRMVERSION VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  REVISION VARCHAR(255) DEFAULT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+	
+CREATE TABLE snmp_blades (
+  SNMP_ID INTEGER NOT NULL AUTO_INCREMENT,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  SYSTEM VARCHAR(255) DEFAULT NULL, 
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_storages (
+  ID INTEGER NOT NULL AUTO_INCREMENT DEFAULT NULL,
+  SNMP_ID INTEGER DEFAULT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  MODEL VARCHAR(255) DEFAULT NULL,
+  DISKSIZE INTEGER DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  FIRMWARE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_drives (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  LETTER VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  FILESYSTEM VARCHAR(255) DEFAULT NULL,
+  TOTAL INTEGER DEFAULT NULL,
+  FREE INTEGER DEFAULT NULL,
+  NUMFILES INTEGER DEFAULT NULL,
+  VOLUMN VARCHAR(255) DEFAULT NULL,
+  LABEL VARCHAR(255) DEFAULT NULL,
+  SERIAL VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_powersupplies (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER DEFAULT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  REFERENCE VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  REVISION VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_fans (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  REFERENCE VARCHAR(255) DEFAULT NULL,
+  REVISION VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_firewalls (
+  SNMP_ID INTEGER NOT NULL AUTO_INCREMENT,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  SYSTEM VARCHAR(255) DEFAULT NULL, 
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_switchinfos (
+  SNMP_ID INTEGER NOT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_loadbalancers (
+  SNMP_ID INTEGER NOT NULL AUTO_INCREMENT,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  SYSTEM VARCHAR(255) DEFAULT NULL, 
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_computers (
+  SNMP_ID INTEGER NOT NULL AUTO_INCREMENT,
+  SYSTEM VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+		
+CREATE TABLE snmp_cards (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  REFERENCE VARCHAR(255) DEFAULT NULL,
+  FIRMWARE VARCHAR(255) DEFAULT NULL,
+  SOFTWARE VARCHAR(255) DEFAULT NULL,
+  REVISION VARCHAR(255) DEFAULT NULL,
+  SERIALNUMBER VARCHAR(255) DEFAULT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_softwares (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  INSTALLDATE VARCHAR(255) DEFAULT NULL,
+  COMMENTS TEXT,
+  VERSION VARCHAR(255) default NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_memories (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  CAPACITY VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_cpus (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  SPEED VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  MANUFACTURER VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_inputs (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  DESCRIPTION VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_ports (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,
+  TYPE VARCHAR(255) DEFAULT NULL,
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_sounds (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,  
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_videos (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,  
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+
+CREATE TABLE snmp_modems (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,  
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+
+CREATE TABLE snmp_localprinters (
+  ID INTEGER NOT NULL AUTO_INCREMENT,
+  SNMP_ID INTEGER NOT NULL,
+  NAME VARCHAR(255) DEFAULT NULL,  
+  PRIMARY KEY (ID, SNMP_ID)
+) DEFAULT CHARSET=UTF8;
+
+
+CREATE TABLE snmp_accountinfo (
+SNMP_ID INTEGER NOT NULL,
+TAG VARCHAR(255) default 'NA',
+primary key(SNMP_ID),
+INDEX TAG (TAG)
+) ENGINE=INNODB DEFAULT CHARSET=UTF8;
+
+CREATE TABLE snmp_laststate (
+SNMP_ID INTEGER NOT NULL,
+COMMON VARCHAR(255) DEFAULT NULL,
+PRINTERS VARCHAR(255) DEFAULT NULL,
+TRAYS VARCHAR(255) DEFAULT NULL,
+CARTRIDGES VARCHAR(255) DEFAULT NULL,
+NETWORKS VARCHAR(255) DEFAULT NULL,
+SWITCHS VARCHAR(255) DEFAULT NULL,
+BLADES VARCHAR(255) DEFAULT NULL,
+STORAGES VARCHAR(255) DEFAULT NULL,
+DRIVES VARCHAR(255) DEFAULT NULL,
+POWERSUPPLIES VARCHAR(255) DEFAULT NULL,
+FANS VARCHAR(255) DEFAULT NULL,
+SWITCHINFOS VARCHAR(255) DEFAULT NULL,
+LOADBALANCERS VARCHAR(255) DEFAULT NULL,
+CARDS VARCHAR(255) DEFAULT NULL,
+COMPUTERS VARCHAR(255) DEFAULT NULL,
+SOFTWARES VARCHAR(255) DEFAULT NULL,
+MEMORIES VARCHAR(255) DEFAULT NULL,
+CPUS VARCHAR(255) DEFAULT NULL,
+INPUTS VARCHAR(255) DEFAULT NULL,
+PORTS VARCHAR(255) DEFAULT NULL,
+SOUNDS VARCHAR(255) DEFAULT NULL,
+VIDEOS VARCHAR(255) DEFAULT NULL,
+MODEMS VARCHAR(255) DEFAULT NULL,
+LOCALPRINTERS VARCHAR(255) DEFAULT NULL,
+PRIMARY KEY (SNMP_ID) ) DEFAULT CHARSET=UTF8;
+
+INSERT INTO config VALUES ('INVENTORY_CACHE_REVALIDATE',7,'','the engine will clean the inventory cache structures');
+ALTER TABLE groups CHANGE REVALIDATE_FROM REVALIDATE_FROM INT(11) default 0;
+UPDATE groups set REVALIDATE_FROM = 0 where REVALIDATE_FROM is null;
+
+DELETE FROM config WHERE name='LOCAL_SERVER' or name='LOCAL_PORT';
+
+INSERT INTO config VALUES ('SESSION_VALIDITY_TIME',600,'','Validity of a session (prolog=>postinventory)');
+
+CREATE TABLE ssl_store (
+ID INTEGER NOT NULL AUTO_INCREMENT,
+FILE LONGBLOB DEFAULT NULL,
+AUTHOR VARCHAR(255) DEFAULT NULL,
+FILE_NAME VARCHAR(255) DEFAULT NULL,
+FILE_TYPE VARCHAR(20) DEFAULT NULL,
+DESCRIPTION VARCHAR(255) DEFAULT NULL,
+PRIMARY KEY (ID) ) DEFAULT CHARSET=UTF8;
+
+INSERT INTO config VALUES ('DOWNLOAD_REDISTRIB',1,'','Use redistribution servers');
+ALTER TABLE snmp_loadbalancers ADD COLUMN MANUFACTURER varchar(255) DEFAULT NULL;
+ALTER TABLE snmp_loadbalancers ADD COLUMN TYPE varchar(255) DEFAULT NULL;
+
